@@ -1,5 +1,5 @@
 from nonebot import on_notice,on_command,on_regex
-from nonebot.adapters.onebot.v11 import NoticeEvent,Bot,MessageEvent,Message
+from nonebot.adapters.onebot.v11 import NoticeEvent,Bot,MessageEvent,Message,MessageSegment
 from nonebot.permission import SUPERUSER
 from nonebot.params import CommandArg,ArgPlainText,RegexGroup
 from nonebot.matcher import Matcher
@@ -12,12 +12,9 @@ from nonebot.adapters.onebot.v11.permission import (
 from time import sleep
 from .config import *
 from .utils import *
-try:
-    import py7zr
-except:
-    pass
+
 from nonebot.plugin import PluginMetadata
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 __plugin_meta__ = PluginMetadata(
     name="求生服务器操作",
     description='群内对服务器的简单操作',
@@ -36,13 +33,14 @@ rename_vpk = on_regex(
         r"^求生地图\s*(\S+.*?)\s*(改|改名)?\s*(\S+.*?)\s*$",
     flags=  re.S,
     block= True,
-    priority= 19,
+    priority= 20,
     permission= Master,
 )
-find_vpk = on_command("map",aliases={"求生地图","查看求生地图"},priority=20,block=True)
-del_vpk = on_command("del_map",aliases={"删除求生地图","删除地图"},priority=20,block=True,permission= Master)
-
-
+find_vpk = on_command("l4_map",aliases={"求生地图","查看求生地图"},priority=25,block=True)
+del_vpk = on_command("l4_del_map",aliases={"求生地图删除","地图删除"},priority=20,block=True,permission= Master)
+anne_player = on_command('Ranne',aliases={"求生anne"},priority=20,block=True)
+steam_bind = on_command('Rbind',aliases={'steam绑定','求生绑定','anne绑定'},priority=20,block=True)
+del_bind = on_command('del_bind',aliases={'steam解绑','求生解绑','anne解绑'},priority=20,block=True)
 
 @up.handle()
 async def _(bot:Bot ,event: NoticeEvent, matcher: Matcher):
@@ -68,27 +66,12 @@ async def _(bot:Bot ,event: NoticeEvent, matcher: Matcher):
         await up.finish("获取文件失败，可能文件已损坏")
     else:
         pass
-
-    # 获取文件名
-    zip_dir = os.path.dirname(down_file)
-    logger.info('文件名为：' + name)
+    
     original_vpk_files = []
     original_vpk_files = get_vpk(original_vpk_files,map_path)
-    logger.info(original_vpk_files)
-    # 解压
-    if name.endswith('.zip'):
-        await up.send('zip文件已下载,正在解压')
-        with support_gbk(ZipFile(down_file, 'r')) as zip_ref:
-            zip_ref.extractall(zip_dir)
-        os.remove(down_file)
-    elif name.endswith('.7z'):
-        await up.send('7z文件已下载,正在解压')
-        with py7zr.SevenZipFile(down_file, 'r') as z:
-            z.extractall(map_path)
-        os.remove(down_file)
-    elif name.endswith('.vpk'):
-        await up.send('vpk文件已下载')
-        
+    msg =open_packet
+    await up.send(msg)
+    
     sleep(1)
     extracted_vpk_files = []
     extracted_vpk_files = get_vpk(extracted_vpk_files,map_path)
@@ -108,7 +91,11 @@ async def _(bot:Bot,event: MessageEvent):
     name_vpk = get_vpk(name_vpk,map_path)
     logger.info("获取文件列表成功")
     mes = "当前服务器下有以下vpk文件"
-    await up.finish(mes_list(mes,name_vpk).replace(" ",""))
+    msg = mes_list(mes,name_vpk).replace(" ","")
+    if l4_image:
+        await find_vpk.finish(MessageSegment.image(text_to_png(msg)))
+    else:
+        await find_vpk.finish(msg)
 
 @del_vpk.handle()
 async def _(matcher:Matcher,args:Message = CommandArg()):
@@ -134,4 +121,30 @@ async def _(matched: Tuple[int,str, str] = RegexGroup(),):
         if map_name:
             await rename_vpk.finish('改名成功\n原名:'+ map_name +'\n新名称:' + rename)
     except ValueError:
-        await rename_vpk.finish('参数错误,请输入格式如【求生地图 5 改名 map.vpk】,或者输入【求生地图】获取全部名称')
\ No newline at end of file
+        await rename_vpk.finish('参数错误,请输入格式如【求生地图 5 改名 map.vpk】,或者输入【求生地图】获取全部名称')
+        
+@anne_player.handle()
+async def _(event:MessageEvent,args:Message = CommandArg()):
+    name = args.extract_plain_text()
+    name = name.strip()
+    usr_id = event.user_id
+    # 没有参数则从json里找数据
+    msg = search_anne(name,usr_id)
+    await anne_player.finish(msg)
+        
+@steam_bind.handle()
+async def _(event:MessageEvent,args:Message = CommandArg()):
+    tag = args.extract_plain_text()
+    tag = tag.strip()
+    if tag=="" or tag.isspace():
+        await steam_bind.finish("虚空绑定?")
+    usr_id = str(event.user_id)
+    nickname = event.sender.card or event.sender.nickname
+    msg = bind_steam(usr_id,tag,nickname)
+    await steam_bind.finish(msg)
+
+@del_bind.handle()
+async def _(event:MessageEvent):
+    usr_id = event.user_id
+    await del_bind.finish(name_exist(usr_id))
+    
\ No newline at end of file
